@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown the shutdown/reboot/suspend/hibernate
- * Copyright (C) 2009 2010  Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
 #include "preferences.h"
 #include "info.h"
 #include "calendar.h"
+#include "passwd.h"
+#include "editor.h"
 
 bool timeRunning;
 bool lockMyScreen;
@@ -28,6 +30,7 @@ extern int fontS1;    // ""
 extern int fontS2;    // ""
 extern int fontS3;    // ""
 extern QDate setCalendarDate; //variable declared in calendar.cpp
+bool lockAll = false;
 
 Gui::Gui(QWidget *parent): QWidget(parent){
 
@@ -36,7 +39,6 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      finishedExecuted = false;
      timeRunning = false;
      logFileSize = 1.5;
-     lockAll = false;
 
      datetime = QDateTime::currentDateTime();
      elapsedTime.start();
@@ -52,6 +54,12 @@ Gui::Gui(QWidget *parent): QWidget(parent){
    //InfoMessageBox
      infoBox = new Info(this);
 
+   //ChangePassword
+     checkPassword = new PassWord(this);
+
+   //Editor
+     editor = new Editor(this);
+
    //Changing SizePolicy for Spacers
      horizontalSpacer1->changeSize(40,45,QSizePolicy::Expanding,QSizePolicy::Expanding);
      horizontalSpacer3->changeSize(85,13,QSizePolicy::Maximum,QSizePolicy::Expanding);
@@ -162,6 +170,9 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      connect(calendarBox, SIGNAL(aDateWasSet()), this, SLOT(setDate()));
      connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(beforeQuit())); //save window size / logs and unregister qshutdown
      connect(quit_action, SIGNAL(triggered()), qApp, SLOT(quit())); //contextmenu "Quit" for the systray quits Programm
+     connect(checkPassword, SIGNAL(success()), editor, SLOT(show())); //if correct password was entered open editor
+     connect(editor, SIGNAL(saved()), this, SLOT(updateLock()));      //update to see if Lock_all was (de)activated
+     connect(pref, SIGNAL(editConf()), checkPassword, SLOT(show()));  //ask for password when button was pressed at preferences
 }
 
 Gui::~Gui(){ delete font1; delete font2; delete font3; }
@@ -263,8 +274,6 @@ void Gui::keyPressEvent(QKeyEvent *kEvent){
            else
              log_action->setChecked(true);
          }
-         if(kEvent->key() == Qt::Key_P)
-           pref->show();
          if(kEvent->key() == Qt::Key_Q)
            qApp->quit();
        }
@@ -272,50 +281,12 @@ void Gui::keyPressEvent(QKeyEvent *kEvent){
          setInfoText();
          infoBox->show();
        }
+       if(kEvent->key() == Qt::Key_P)
+         pref->show();
      }
      if(kEvent->modifiers() == Qt::ShiftModifier){
-       if(kEvent->key() == Qt::Key_E){
-      #ifdef Q_OS_WIN32
-         QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
-      #else //!Q_OS_WIN32
-         QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
-      #endif //Q_OS_WIN32
-         QProcess editConf;
-         QString editor;
-         QString su;
-         if(QFileInfo("/usr/bin/gksudo").exists())
-           su = "gksudo";
-         else if(QFileInfo("/usr/bin/gksu").exists())
-           su = "gksu";
-         else if(QFileInfo("/usr/bin/kdesudo").exists())
-           su = "kdesudo";
-         else if(QFileInfo("/usr/bin/kdesu").exists())
-           su = "kdesu";
-         if(QFileInfo("/usr/bin/gedit").exists())
-           editor = "gedit";
-         else if(QFileInfo("/usr/bin/kate").exists())
-           editor = "kate";
-         else if(QFileInfo("/usr/bin/kwrite").exists())
-           editor = "kwrite";
-         else if(QFileInfo("/usr/bin/emacs").exists())
-           editor = "emacs";
-         editConf.start(su, QStringList() << editor << file);
-         if(editConf.waitForFinished()){
-        #ifdef Q_OS_WIN32
-           QSettings settings(file, QSettings::IniFormat);
-        #else //!Q_OS_WIN32
-           QSettings settings(file, QSettings::NativeFormat);
-        #endif //Q_OS_WIN32
-           if(settings.value("Lock_all").toBool()){
-             lockAll = true;
-             lockEverything(true);
-           }
-           else{
-             lockAll = false;
-             lockEverything(false);
-           }
-         }
-       }
+       if(kEvent->key() == Qt::Key_E)
+         checkPassword->show(); //ask for password to edit qshutdown.conf
      }
 }
 
@@ -482,7 +453,7 @@ void Gui::Time(){
 void Gui::saveWindowSize(){
    #ifdef Q_OS_WIN32
      QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
-     QSettings settings(file, QSettings::IniFormat);
+     QSettings settings(file, QSettings::NativeFormat);
    #else //!Q_OS_WIN32
      QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
      QSettings settings(file, QSettings::NativeFormat);
@@ -566,7 +537,7 @@ void Gui::loadSettings(){
 /***************** create file and it's entries *****************/
 #ifdef Q_OS_WIN32
      QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
-     QSettings settings(file, QSettings::IniFormat);
+     QSettings settings(file, QSettings::NativeFormat);
 #else //!Q_OS_WIN32
      QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
      QSettings settings(file, QSettings::NativeFormat);
@@ -612,6 +583,8 @@ void Gui::loadSettings(){
        settings.setValue("Logfile/size", 1.5);
      if(!settings.contains("Lock_screen"))
        settings.setValue("Lock_screen", true);
+     if(!settings.contains("Autostart"))
+       settings.setValue("Autostart", false);
 
 /***************** read files entries *****************/
      timeEdit->setTime(QTime(settings.value("Time/time_hour").toInt(),settings.value("Time/time_minute").toInt()));
@@ -689,7 +662,6 @@ void Gui::lockEverything(bool actual){
      if(timeRunning){
        reset_action->setVisible(true);
        reset_action->setDisabled(actual);
-       pref_action->setDisabled(actual);
        quit_action->setDisabled(actual);
        log_action->setDisabled(actual);
        toolButton->setDisabled(actual);
@@ -702,7 +674,6 @@ void Gui::lockEverything(bool actual){
        else
          spin->setDisabled(actual);
        reset_action->setDisabled(actual);
-       pref_action->setDisabled(actual);
        quit_action->setDisabled(actual);
        log_action->setDisabled(actual);
        power_actions->setDisabled(actual);
@@ -713,6 +684,17 @@ void Gui::lockEverything(bool actual){
        foreach(QWidget * widgetPtr, widgetList)
          widgetPtr->setDisabled(actual);
      }
+     QList<QWidget*> widgetList;
+     widgetList << pref->comboBox << pref->timeEdit << pref->spin
+                << pref->radio1 << pref->radio2
+                << pref->autostart << pref->lock << pref->countdown
+                << pref->log << pref->reset;
+     foreach(QWidget * widgetPtr, widgetList)
+       widgetPtr->setDisabled(actual);
+     if(pref->log->isEnabled() && pref->log->isChecked())
+       pref->spinBox->setDisabled(false);
+     else
+       pref->spinBox->setDisabled(true);
 }
 void Gui::reset(){
      setWindowTitle("'qshutdown'");
@@ -768,3 +750,20 @@ void Gui::showCalendarBox(){
        calendarBox->calendarWidget->blockSignals(false);
      calendarBox->show();
 }
+
+void Gui::updateLock(){
+    #ifdef Q_OS_WIN32
+       QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
+    #else //!Q_OS_WIN32
+       QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
+    #endif //Q_OS_WIN32
+       QSettings settings(file, QSettings::NativeFormat);
+       if(settings.value("Lock_all").toBool()){
+         lockAll = true;
+         lockEverything(true);
+       }
+       else{
+         lockAll = false;
+         lockEverything(false);
+       }
+}
