@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010  Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,8 @@
 class Preferences;
 class Info;
 class Calendar;
+class PassWord;
+class Editor;
 
 class Gui : public QWidget, public Ui::Gui {
      Q_OBJECT // important for creating own singals and slots
@@ -66,11 +68,12 @@ class Gui : public QWidget, public Ui::Gui {
      int             n; //to check if i==0 was skipped
      QFont           *font1, *font2, *font3;
      bool            finishedExecuted;
-     bool            lockAll;
      double          logFileSize;
      Preferences     *pref;
      Info            *infoBox;
      Calendar        *calendarBox;
+     PassWord        *checkPassword;
+     Editor          *editor;
 
      // defining signals and slots
  
@@ -91,10 +94,11 @@ class Gui : public QWidget, public Ui::Gui {
      void showCalendarBox();
      void setDate();
      void lockEverything(bool actual);
+     void updateLock();
     public slots:
      Q_SCRIPTABLE void showRunningProgram();
     protected:
-     void keyPressEvent(QKeyEvent *kEvent);
+     void keyPressEvent(QKeyEvent* kEvent);
      virtual void closeEvent(QCloseEvent* window_close);
 };
 
