@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010  Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ Info::Info(QWidget *parent): QTextEdit(parent){
      setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);
      setReadOnly(true);
      resize(500,450);
-     setWindowTitle("Info");
+     setWindowTitle(tr("Info"));
 }
 
 Info::~Info(){ }
