@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010  Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,21 +23,24 @@ QString fonts = "Times New Roman";
 int fontS1 = 13;
 int fontS2 = 18;
 int fontS3 = 11;
+extern bool lockAll; //declared in gui.cpp
 
 Preferences::Preferences(QWidget *parent): QDialog(parent){
 
-	setupUi(this);
+     setupUi(this);
 
      setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);    //always in front
 
 /***************** load settings from the conf file *****************/
 
 #ifdef Q_OS_WIN32
+     lockS->setDisabled(true); //if there is a command for locking the display in Windows, remove this line
+                               //and add the command to power.cpp
      file = QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf";
-     settings = new QSettings(file, QSettings::IniFormat);
+     settings = new QSettings(file, QSettings::NativeFormat);
 #else //!Q_OS_WIN32
      file = QDir::homePath() + "/.qshutdown/qshutdown.conf";
-     settings = new QSettings(file, QSettings::IniFormat);
+     settings = new QSettings(file, QSettings::NativeFormat);
 #endif //Q_OS_WIN32
 
      msgBox = new QMessageBox(this);
@@ -55,6 +58,7 @@ Preferences::Preferences(QWidget *parent): QDialog(parent){
      connect(fontComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(fontChanged(QString)));
      connect(buttonBox, SIGNAL(rejected()), this, SLOT(resetFont()));
      connect(lockS, SIGNAL(toggled(bool)), this, SLOT(lockScreen()));
+     connect(confEditButton, SIGNAL(clicked(bool)), this, SLOT(sendEditSignal()));
 }
 
 Preferences::~Preferences(){ delete settings; }
@@ -88,6 +92,7 @@ void Preferences::loadSettings(){
      warn->setChecked(settings->value("CheckBoxes/warnings").toBool());
      log->setChecked(settings->value("Logfile/logging").toBool());
      lockS->setChecked(settings->value("Lock_screen").toBool());
+     autostart->setChecked(settings->value("Autostart").toBool());
 }
 
 void Preferences::saveToConfFile(){
@@ -109,7 +114,9 @@ void Preferences::saveToConfFile(){
        settings->setValue("CheckBoxes/warnings", warn->isChecked());
        settings->setValue("Logfile/logging", log->isChecked());
        settings->setValue("Lock_screen", lockS->isChecked());
+       settings->setValue("Autostart", autostart->isChecked());
      }
+     autostartFile();
 }
 
 void Preferences::resetSettings(){
@@ -164,3 +171,29 @@ void Preferences::resetFont(){
      fontS3 = settings->value("Fonts/font3").toInt();
      changeFont();
 }
+
+void Preferences::sendEditSignal(){ editConf(); }
+
+void Preferences::autostartFile(){
+    #ifndef Q_OS_WIN32
+     QFile autostartFile(QDir::homePath() + "/.config/autostart/qshutdown.desktop");
+     if(autostart->isChecked() && !autostartFile.exists()){
+       if(!QDir(QDir::homePath() + "/.config/autostart").exists()){
+         QDir dir(QDir::homePath() + "/.config/autostart");
+         dir.mkdir(QDir::homePath() + "/.config/autostart");
+       }
+       if(!autostartFile.open(QIODevice::ReadWrite | QIODevice::Text)){
+         qCritical("E: Can not open qshutdown.conf!");
+         return;
+       }
+         QString autostartContent("[Desktop Entry]\nName=qshutdown\n"
+           "Name[de_DE]=qshutdown\nExec=qshutdown\nTerminal=false\n"
+           "Type=Application\nIcon=red_glasses\nCategories=Utility");
+         QTextStream out(&autostartFile);
+         out << autostartContent;
+         autostartFile.close();
+     }
+     if(autostartFile.exists() && !autostart->isChecked())
+       autostartFile.remove();
+    #endif
+}
